@@ -2,12 +2,53 @@
 #include <string.h>
 
 #include "css/cssvalue.h"
+#include "view/htmlview.h"
 #include "layout/htmlbox.h"
 #include "layout/htmlstyle.h"
 #include "util/htmlglobalatoms.h"
 
 static HtmlStyle *default_style = NULL;
 
+static gint
+html_style_get_base_size ()
+{
+	gint base_size = 14;
+	PangoFontDescription *font_desc;
+	GtkSettings *settings;
+	gchar *font_name;
+
+	settings = gtk_settings_get_default ();
+	g_object_get (G_OBJECT (settings), "gtk-font-name", &font_name, NULL);
+	font_desc = pango_font_description_from_string (font_name);
+        g_free (font_name);
+        
+ 	if (font_desc) { 
+	    base_size = pango_font_description_get_size (font_desc) / PANGO_SCALE;
+            pango_font_description_free (font_desc);
+	}
+	
+	return base_size;
+}
+
+static HtmlColor*
+html_style_get_default_text_color ()
+{
+	GtkStyle *style = gtk_rc_get_style_by_paths (gtk_settings_get_default(),
+						     "GtkHtml",
+						     "HtmlView",
+						     HTML_TYPE_VIEW);
+	GdkColor text_color;
+	if (!style)
+	  {
+	    style = gtk_style_new ();
+	  }
+	text_color = style->text[GTK_STATE_NORMAL];
+
+	return html_color_new_from_rgb (text_color.red,
+					text_color.green,
+					text_color.blue);
+}
+
 void
 html_length_set_value (HtmlLength *length, gint value, HtmlLengthType type)
 {
@@ -144,6 +185,11 @@ html_default_style_new (void)
 	HtmlStyleBackground *background = html_style_background_new ();
 	HtmlStyleBorder *border = html_style_border_new ();
 	HtmlStyleOutline *outline = html_style_outline_new ();
+        gchar *font_name;
+        GtkSettings *settings;
+        PangoFontDescription *font_desc;
+        const gchar *family;
+
 	/* Set refcount to 1 so it never will be deallocated */
 	result->refcount = 1;
 	
@@ -161,15 +207,31 @@ html_default_style_new (void)
 	
 	html_style_set_outline_width (result, HTML_BORDER_WIDTH_MEDIUM);
 
+        settings = gtk_settings_get_default ();
+        g_object_get (G_OBJECT (settings), "gtk-font-name", &font_name, NULL);
+        font_desc = pango_font_description_from_string (font_name);
+        g_free (font_name);
+        
 	/* FIXME: This should probably not be here */
-	inherited->font_spec = html_font_specification_new ("sans", HTML_FONT_STYLE_NORMAL, 
-							    HTML_FONT_VARIANT_NORMAL, 
-							    HTML_FONT_WEIGHT_NORMAL, 
-							    HTML_FONT_STRETCH_NORMAL,
-							    HTML_FONT_DECORATION_NONE, 14);
+        family = pango_font_description_get_family (font_desc);
+        
+        if (!family) {
+                family = "sans";
+        }
 
-	/* Set the default color to black */
-	html_style_set_color (result, html_color_new_from_rgb (0, 0, 0));
+	inherited->font_spec = 
+                html_font_specification_new ((gchar *) family, 
+                                             HTML_FONT_STYLE_NORMAL, 
+                                             HTML_FONT_VARIANT_NORMAL, 
+                                             HTML_FONT_WEIGHT_NORMAL, 
+                                             HTML_FONT_STRETCH_NORMAL,
+                                             HTML_FONT_DECORATION_NONE, 
+                                             html_style_get_base_size ());
+
+        pango_font_description_free (font_desc);
+        
+	/* Set the default color to match the GTK+ theme */
+	html_style_set_color (result, html_style_get_default_text_color ());
 	
 	return result;
 }
